==> haskell-sourcemap-0.1.6-147-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-5PmPLlN65D0DNXlpO7nq3s
key: sourcemap-0.1.6-5PmPLlN65D0DNXlpO7nq3s
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 443fe99206fde90374f06542725cca25
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-5PmPLlN65D0DNXlpO7nq3s
depends:
    aeson-1.4.6.0-53gmO5YtU8gIZiWG8EtnAc
    attoparsec-0.13.2.3-BbILE9CT2Wt3O8KWGStqZj base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 text-1.2.3.1
    unordered-containers-0.2.10.0-AdFIXUUlSRM50nV4OuQt9A
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sourcemap-0.1.6-149-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sourcemap.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sourcemap
version: 0.1.6
id: sourcemap-0.1.6-DJ83DjmC1a8B2zhQXW8MF7
key: sourcemap-0.1.6-DJ83DjmC1a8B2zhQXW8MF7
license: BSD-3-Clause
copyright: 2012 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
stability: alpha
synopsis: Implementation of source maps as proposed by Google and Mozilla.
description:
    Implementation of source maps, revision 3, proposed by Google and Mozilla here
    <https://wiki.mozilla.org/DevTools/Features/SourceMap> and here
    <https://docs.google.com/document/d/1U1RGAehQwRypUTovF1KRlpiOFze0b-_2gc6fAH0KY0k/edit>
category: Development
abi: 35aea9e960c04f52bfe97dfcee1fae28
exposed: True
exposed-modules:
    SourceMap SourceMap.Types
hidden-modules: VLQ
import-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/sourcemap-0.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/sourcemap-0.1.6
hs-libraries: HSsourcemap-0.1.6-DJ83DjmC1a8B2zhQXW8MF7
depends:
    aeson-1.4.6.0-IYkWE2kAqOg3BtypRoad0s
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    bytestring-0.10.8.2 process-1.6.5.0 text-1.2.3.1
    unordered-containers-0.2.10.0-98MsUmwXpKo1DE5wGxzrlx
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-sourcemap/html/sourcemap.haddock
haddock-html: /usr/share/doc/haskell-sourcemap/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
